package com.zd.laboratory.service;

import java.util.List;
import com.zd.laboratory.domain.LabValueSegmentSite;

/**
 * 违规-分值段设置Service接口
 * 
 * @author zd
 * @date 2021-12-13
 */
public interface ILabValueSegmentSiteService 
{
    /**
     * 查询违规-分值段设置
     * 
     * @param id 违规-分值段设置主键
     * @return 违规-分值段设置
     */
    public LabValueSegmentSite selectLabValueSegmentSiteById(Long id);

    /**
     * 查询违规-分值段设置列表
     * 
     * @param labValueSegmentSite 违规-分值段设置
     * @return 违规-分值段设置集合
     */
    public List<LabValueSegmentSite> selectLabValueSegmentSiteList(LabValueSegmentSite labValueSegmentSite);

    /**
     * 新增违规-分值段设置
     * 
     * @param labValueSegmentSite 违规-分值段设置
     * @return 结果
     */
    public int insertLabValueSegmentSite(LabValueSegmentSite labValueSegmentSite);

    /**
     * 修改违规-分值段设置
     * 
     * @param labValueSegmentSite 违规-分值段设置
     * @return 结果
     */
    public int updateLabValueSegmentSite(LabValueSegmentSite labValueSegmentSite);

    /**
     * 批量删除违规-分值段设置
     * 
     * @param ids 需要删除的违规-分值段设置主键集合
     * @return 结果
     */
    public int deleteLabValueSegmentSiteByIds(Long[] ids);

    /**
     * 删除违规-分值段设置信息
     * 
     * @param id 违规-分值段设置主键
     * @return 结果
     */
    public int deleteLabValueSegmentSiteById(Long id);
}
