package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabValueSegmentSite;
import com.zd.laboratory.service.ILabValueSegmentSiteService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.core.web.page.TableDataInfo;

/**
 * 违规-分值段设置Controller
 *
 * @author zd
 * @date 2021-12-13
 */
@RestController
@Api(tags = "【违规-分值段设置】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@RequestMapping("/valueSegment")
public class LabValueSegmentSiteController extends BaseController
{
    @Autowired
    private ILabValueSegmentSiteService labValueSegmentSiteService;

    /**
     * 查询违规-分值段设置列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VALUESEGMENT + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询违规-分值段设置列表")
    public TableDataInfo<LabValueSegmentSite> list(LabValueSegmentSite labValueSegmentSite)
    {
        startPage();
        List<LabValueSegmentSite> list = labValueSegmentSiteService.selectLabValueSegmentSiteList(labValueSegmentSite);
        return getDataTable(list);
    }

    /**
     * 导出违规-分值段设置列表
     */
    @ApiOperation(value = "导出违规-分值段设置列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VALUESEGMENT + PerFun.EXPORT)
    @Log(title = "违规-分值段设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabValueSegmentSite labValueSegmentSite) throws IOException
    {
        List<LabValueSegmentSite> list = labValueSegmentSiteService.selectLabValueSegmentSiteList(labValueSegmentSite);
        ExcelUtil<LabValueSegmentSite> util = new ExcelUtil<LabValueSegmentSite>(LabValueSegmentSite.class);
        util.exportExcel(response, list, "违规-分值段设置数据");
    }

    /**
     * 获取违规-分值段设置详细信息
     */
    @ApiOperation(value = "获取违规-分值段设置详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VALUESEGMENT + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabValueSegmentSite> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labValueSegmentSiteService.selectLabValueSegmentSiteById(id));
    }

    /**
     * 新增违规-分值段设置
     */
    @ApiOperation(value = "新增违规-分值段设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VALUESEGMENT + PerFun.ADD)
    @Log(title = "违规-分值段设置", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabValueSegmentSite labValueSegmentSite)
    {
        return ResultData.result(labValueSegmentSiteService.insertLabValueSegmentSite(labValueSegmentSite));
    }

    /**
     * 修改违规-分值段设置
     */
    @ApiOperation(value = "修改违规-分值段设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VALUESEGMENT + PerFun.EDIT)
    @Log(title = "违规-分值段设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabValueSegmentSite labValueSegmentSite)
    {
        return  ResultData.result(labValueSegmentSiteService.updateLabValueSegmentSite(labValueSegmentSite));
    }

    /**
     * 删除违规-分值段设置
     */
    @ApiOperation(value = "删除违规-分值段设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_VALUESEGMENT + PerFun.REMOVE)
    @Log(title = "违规-分值段设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labValueSegmentSiteService.deleteLabValueSegmentSiteByIds(ids));
    }
}
